@@ -6,6 +6,7 @@
 
 extern void _GMP_init(void);
 extern void _GMP_destroy(void);
+extern void _GMP_memfree(void);
 
 extern int  primality_pretest(mpz_t n);
 
@@ -16,8 +17,6 @@ extern void surround_primes(mpz_t n, UV* prev, UV* next, UV skip_width);
 extern void _GMP_pn_primorial(mpz_t prim, UV n);
 extern void _GMP_primorial(mpz_t prim, UV n);
 extern void consecutive_integer_lcm(mpz_t m, UV B);
-extern void bernfrac(mpz_t num, mpz_t den, mpz_t n);
-extern void harmfrac(mpz_t num, mpz_t den, mpz_t n);
 extern void stirling(mpz_t r, unsigned long n, unsigned long m, UV type);
 extern void binomial(mpz_t r, UV n, UV k);
 extern void partitions(mpz_t npart, UV n);
@@ -33,13 +32,9 @@ extern UV   prime_power(mpz_t prime, mpz_t n);
 extern void exp_mangoldt(mpz_t res, mpz_t n);
 
 extern uint32_t* partial_sieve(mpz_t start, UV length, UV maxprime);
-extern char* pidigits(UV n);
-extern char* bernreal(mpz_t zn, unsigned long prec);
-extern char* harmreal(mpz_t zn, unsigned long prec);
-extern char* zetareal(mpf_t r, unsigned long prec);
-extern char* riemannrreal(mpf_t r, unsigned long prec);
-extern char* lambertwreal(mpf_t r, unsigned long prec);
 
+extern void prime_count_lower(mpz_t pc, mpz_t n);
+extern void prime_count_upper(mpz_t pc, mpz_t n);
 extern void count_primes(mpz_t count, mpz_t lo, mpz_t hi);
 extern UV* sieve_primes(mpz_t low, mpz_t high, UV k, UV *rn);
 extern UV* sieve_twin_primes(mpz_t low, mpz_t high, UV twin, UV *rn);
